==> aLBI_0.1.5.tar.gz: aLBI/R/DataDescription.R <==
#' CPdata: Example dataset for aLBI package
#'
#' This dataset contains description of CPdata.
#'
#' @name CPdata
#' @docType data
#' @usage data(CPdata)
#' @format A data frame with [number of rows] rows and 11 columns:
#' \describe{
#'   \item{\code{A}}{[description of column A]}
#'   \item{\code{B}}{[description of column B]}
#'   \item{\code{C}}{[description of column C]}
#'   \item{\code{D}}{[description of column D]}
#'   \item{\code{E}}{[description of column E]}
#'   \item{\code{F}}{[description of column F]}
#'   \item{\code{G}}{[description of column G]}
#'   \item{\code{H}}{[description of column H]}
#'   \item{\code{I}}{[description of column I]}
#'   \item{\code{J}}{[description of column J]}
#'   \item{\code{Tx}}{[description of column Tx]}
#' }
#' @source [Include the source of the data if available]
#' @examples
#' data(CPdata)
#' head(CPdata)
NULL  # Include this line to ensure the data is loaded correctly


#' lenfreq01: Example dataset for aLBI package
#'
#' This dataset contains description of lenfreq01.
#'
#' @name lenfreq01
#' @docType data
#' @usage data(lenfreq01)
#' @format A data frame with [number of rows] rows and 2 columns:
#' \describe{
#'   \item{\code{Frequency}}{[description of column Frequency]}
#'   \item{\code{Length}}{[description of column Length]}
#' }
#' @source [Include the source of the data if available]
#' @examples
#' data(lenfreq01)
#' head(lenfreq01)
NULL  # Include this line to ensure the data is loaded correctly

#' lenfreq02: Example dataset for aLBI package
#'
#' This dataset contains description of lenfreq02.
#'
#' @name lenfreq02
#' @docType data
#' @usage data(lenfreq02)
#' @format A data frame with [number of rows] rows and 2 columns:
#' \describe{
#'   \item{\code{Frequency}}{[description of column Frequency]}
#'   \item{\code{LengthClass}}{[description of column LengthClass]}
#' }
#' @source [Include the source of the data if available]
#' @examples
#' data(lenfreq02)
#' head(lenfreq02)
NULL  # Include this line to ensure the data is loaded correctly

==> aLBI_0.1.7.tar.gz: aLBI/R/DataDescription.R <==
#' CPdata: Example dataset for aLBI package
#'
#' This dataset contains description of CPdata.
#'
#' @name CPdata
#' @docType data
#' @usage data(CPdata)
#' @format A data frame with [number of rows] rows and 11 columns:
#' \describe{
#'   \item{\code{A}}{[description of column A]}
#'   \item{\code{B}}{[description of column B]}
#'   \item{\code{C}}{[description of column C]}
#'   \item{\code{D}}{[description of column D]}
#'   \item{\code{E}}{[description of column E]}
#'   \item{\code{F}}{[description of column F]}
#'   \item{\code{G}}{[description of column G]}
#'   \item{\code{H}}{[description of column H]}
#'   \item{\code{I}}{[description of column I]}
#'   \item{\code{J}}{[description of column J]}
#'   \item{\code{Tx}}{[description of column Tx]}
#' }
#' @source [Include the source of the data if available]
#' @examples
#' data(CPdata)
#' head(CPdata)
NULL  # Include this line to ensure the data is loaded correctly


#' lenfreq01: Example dataset for aLBI package
#'
#' This dataset contains description of lenfreq01.
#'
#' @name lenfreq01
#' @docType data
#' @usage data(lenfreq01)
#' @format A data frame with [number of rows] rows and 2 columns:
#' \describe{
#'   \item{\code{Frequency}}{[description of column Frequency]}
#'   \item{\code{Length}}{[description of column Length]}
#' }
#' @source [Include the source of the data if available]
#' @examples
#' data(lenfreq01)
#' head(lenfreq01)
NULL  # Include this line to ensure the data is loaded correctly

#' lenfreq02: Example dataset for aLBI package
#'
#' This dataset contains description of lenfreq02.
#'
#' @name lenfreq02
#' @docType data
#' @usage data(lenfreq02)
#' @format A data frame with [number of rows] rows and 2 columns:
#' \describe{
#'   \item{\code{Frequency}}{[description of column Frequency]}
#'   \item{\code{LengthClass}}{[description of column LengthClass]}
#' }
#' @source [Include the source of the data if available]
#' @examples
#' data(lenfreq02)
#' head(lenfreq02)
NULL  # Include this line to ensure the data is loaded correctly

#' ExData: Example raw lenght dataset for aLBI package
#'
#' This dataset contains description of ExData.
#'
#' @name ExData
#' @docType data
#' @usage data(ExData)
#' @format A data frame with [number of rows] rows and 1 columns:
#' \describe{
#'   \item{\code{Length}}{[description of column Length measured]}
#' }
#' @source [Include the source of the data if available]
#' @examples
#' data(ExData)
#' head(ExData)
NULL  # Include this line to ensure the data is loaded correctly
